@@ -199,6 +199,11 @@ def prompt_for_missing_model_info(
     type=int,
     help="The ID of the Organization to submit the model to",
 )
+@click.option(
+    "-g",
+    "--group_id",
+    help="The ID of the group to submit the model to",
+)
 def submit_model(
     organization_id,
     model_file_path,
@@ -207,6 +212,7 @@ def submit_model(
     auto_confirm,
     quantization,
     input_dims,
+    group_id,
     **kwargs,
 ):
     # Priority: flags, then configCache, then inference, then interactive user input
@@ -237,8 +243,8 @@ def submit_model(
         "name": model_name,
         "framework": framework,
         "quantization": quantization,
-        "from_onspecta": False,  # TODO we should disallow this param in the API
         "inputs": input_dims,
+        "group_id": group_id,
     }
 
     print(
@@ -256,4 +262,4 @@ def submit_model(
     model_link = autodl.upload_model(
         environment, organization_id, model_config, model_file
     )
-    print(f"Done! See {model_link}")
+    print(f"\nDone!\nSee {model_link}")
