@@ -321,7 +321,20 @@ cloud_instances = [
                 "predictor_num_threads": 8,
                 "predictor_latency_scaling_factor": 1.0,
                 "ram": 61,
-                "gpuram": 32,
+                "gpuram": 16,
+            },
+            {
+                "type": "p3.8xlarge",
+                "class": "p3",
+                "hw": "NVIDIA V100 GPUs",
+                "cores": 32,
+                "hyperthreading": False,
+                "usd_per_hr": 12.24,
+                "predictor_target": "p3.8xlarge",
+                "predictor_num_threads": 16,
+                "predictor_latency_scaling_factor": 1.0,
+                "ram": 244,
+                "gpuram": 64,
             },
             {
                 "type": "g3s.xlarge",
@@ -336,6 +349,19 @@ cloud_instances = [
                 "ram": 30.5,
                 "gpuram": 16,
             },
+            {
+                "type": "g5.xlarge",
+                "class": "g5",
+                "hw": "NVIDIA A10G",
+                "cores": 4,
+                "hyperthreading": False,
+                "usd_per_hr": 1.006,
+                "predictor_target": "g5.xlarge",
+                "predictor_num_threads": 4,
+                "predictor_latency_scaling_factor": 1.0,
+                "ram": 16,
+                "gpuram": 24,
+            },
         ],
     },
     {
@@ -848,14 +874,19 @@ supported_hardwares = [
     },
     {
         "name": "NVIDIA T4 GPUs",
-        "vendor": "NVIDIA T4 GPUs",
+        "vendor": "NVIDIA",
         "arch": "NVIDIA T4 GPUs",
     },
     {
         "name": "NVIDIA V100 GPUs",
-        "vendor": "NVIDIA V100 GPUs",
+        "vendor": "NVIDIA",
         "arch": "NVIDIA V100 GPUs",
     },
+    {
+        "name": "NVIDIA A10G",
+        "vendor": "NVIDIA",
+        "arch": "NVIDIA A10G",
+    }
 ]
 
 supported_quants = [
